controller property

LocalHeroController controller
getter/setter pair

An instance which holds the offset from the origin of the leader layer to the origin of the child layers, used when the layer is linked to a LeaderLayer.

The scene must be explicitly recomposited after this property is changed (as described at Layer).

Implementation

LocalHeroController controller;