LocalHeroLeader constructor

const LocalHeroLeader({
  1. Key? key,
  2. required LocalHeroController controller,
  3. Widget? child,
})

Creates a composited transform target widget.

The link property must not be null, and must not be currently being used by any other CompositedTransformTarget object that is in the tree.

Implementation

const LocalHeroLeader({
  Key? key,
  required this.controller,
  Widget? child,
}) : super(key: key, child: child);